@@ -27,7 +27,7 @@
 #define SAMPLE_STORE_SIZE 100
 #define DEFAULT_LOGFILE_NAME "log.txt"
 #define CUSTOMPLOT_YAXIS_RANGE 120
-#define VERSION_NUMBER "1.1"
+#define VERSION_NUMBER "1.3"
 
 MainWindow::MainWindow(ThermaldInterface *thermaldInterface) : QMainWindow(),
     temp_samples(SAMPLE_STORE_SIZE),
@@ -45,7 +45,6 @@ MainWindow::MainWindow(ThermaldInterface *thermaldInterface) : QMainWindow(),
     colors.append(Qt::blue);
     colors.append(Qt::cyan);
     colors.append(Qt::magenta);
-    colors.append(Qt::yellow);
     colors.append(Qt::black);
     colors.append(QColor(200,200,00));
     colors.append(QColor(220,20,60));
@@ -58,6 +57,7 @@ MainWindow::MainWindow(ThermaldInterface *thermaldInterface) : QMainWindow(),
     colors.append(QColor(255,153,18));
     colors.append(QColor(255,69,0));
     colors.append(Qt::gray);
+    colors.append(Qt::yellow);
 
     loadSettings();
 
@@ -111,16 +111,22 @@ void MainWindow::setupPlotWidget()
     m_plotWidget->yAxis->setRange(0, CUSTOMPLOT_YAXIS_RANGE);
     m_plotWidget->legend->setVisible(true);
 
-    pen.setWidth(1);
+    pen.setWidth(5);
 
     currentTempsensorIndex = 0;
+    int active_zone = 0;
     for (uint zone = 0; zone < m_thermaldInterface->getZoneCount(); zone++) {
+        // Trips is indexed by zone. We need to make sure there is a tips item
+        // (even if empty) for each zone.
+        trips.append(QVector<QCPItemLine *>());
 
         zoneInformationType *zone_info = m_thermaldInterface->getZone(zone);
         if (!zone_info)
             continue;
 
-        pen.setColor(colors[zone % colors.count()]);
+        pen.setColor(colors[active_zone % colors.count()]);
+        if ( zone_info->active)
+            active_zone++;
 
         int sensor_cnt_per_zone = m_thermaldInterface->getSensorCountForZone(zone);
         if (sensor_cnt_per_zone <= 0)
@@ -128,7 +134,7 @@ void MainWindow::setupPlotWidget()
 
         pen.setStyle(Qt::SolidLine);
 
-        for (int cnt = 0; cnt < sensor_cnt_per_zone; cnt++) {
+        for (int cnt = 0; zone_info->active && cnt < sensor_cnt_per_zone; cnt++) {
             QString sensor_type;
             QString sensor_name;
 
@@ -168,7 +174,7 @@ void MainWindow::setupPlotWidget()
                 line->start->setCoords(0, temp);
                 line->end->setCoords(SAMPLE_STORE_SIZE - 1, temp);
                 line->setPen(pen);
-                if (temp == m_thermaldInterface->getLowestValidTripTempForZone(zone)) {
+                if (zone_info->active && temp == m_thermaldInterface->getLowestValidTripTempForZone(zone)) {
                     line->setVisible(true);
                     m_thermaldInterface->setTripVisibility(zone, trip, true);
                 } else {
@@ -177,10 +183,11 @@ void MainWindow::setupPlotWidget()
                 }
                 these_trips.append(line);
             }
-            trips.append(these_trips);
+            trips.last().swap(these_trips);
         }
     }
 
+#ifdef DISPLAY_UNKNOWN
     // Now display sensors which are not part of any zone. Users can use this and assign to some zone
     for (uint i = 0; i < m_thermaldInterface->getSensorCount(); ++i) {
         sensorInformationType info;
@@ -220,7 +227,7 @@ void MainWindow::setupPlotWidget()
 
         }
     }
-
+#endif
     connect(&tempUpdateTimer, SIGNAL(timeout()),
             this, SLOT(updateTemperatureDataSlot()));
     tempUpdateTimer.start(temp_poll_interval);
@@ -484,7 +491,10 @@ void MainWindow::showAboutDialog()
     QString str;
     str = QString("<h3>Thermal Monitor %1</h3>"
                   "<p>GUI for Linux thermal daemon (thermald)</p>"
-                  "<p>Copyright (c) 2015, Intel Corporation</p>")
+                  "<p>Copyright (c) 2022, Intel Corporation</p>"
+                  "<p>This program comes with ABSOLUTELY NO WARRANTY</p>"
+                  "<p>This work is licensed under GPL v3</p>"
+                  "<p>Refer to https://www.gnu.org/licenses/gpl-3.0.txt</p>")
             .arg(QString(VERSION_NUMBER));
     QMessageBox::about(this, "About Thermal Monitor", str);
 }
